# pyform

[![PyPI version](https://badge.fury.io/py/pyform.svg)](https://badge.fury.io/py/pyform)
![Python package](https://github.com/shawnlinxl/pyform/workflows/Python%20package/badge.svg)
[![codecov](https://codecov.io/gh/shawnlinxl/pyform/branch/master/graph/badge.svg)](https://codecov.io/gh/shawnlinxl/pyform)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

An Event-Driven Algorithm Trading framework.
